[![build status](https://img.shields.io/travis/fcracker79/event_mill/master.svg?style=flat-square)](https://travis-ci.org/fcracker79/event_mill)

Event Mill
==========

A framework for projections from event stores.
